"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const semaphore_1 = require("@seangenabe/semaphore");
class AsyncIterableMapper {
    constructor(source, transform, { concurrency = Infinity } = {}) {
        this.transform = transform;
        this.semaphore = new semaphore_1.Semaphore(concurrency);
        this.sourceIterator = isAsyncIterable(source)
            ? source[Symbol.asyncIterator]()
            : source[Symbol.iterator]();
    }
    async next() {
        const { done, value } = await this.sourceIterator.next();
        if (done) {
            return { done: true };
        }
        const release = await this.semaphore.wait();
        const result = await this.transform(value);
        release();
        return { done: false, value: result };
    }
    [Symbol.asyncIterator]() {
        return this;
    }
    async toArray() {
        const out = [];
        for await (const element of this) {
            out.push(element);
        }
        return out;
    }
    then(onfulfilled, onrejected) {
        return this.toArray().then(onfulfilled, onrejected);
    }
}
function map(source, transform, options = {}) {
    return new AsyncIterableMapper(source, transform, options);
}
exports.map = map;
function isAsyncIterable(x) {
    return typeof x[Symbol.asyncIterator] === "function";
}
//# sourceMappingURL=index.js.map