"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const t0_1 = require("t0");
const _1 = require("./");
t0_1.test("map single", async () => {
    const source = create([{ a: 2 }]);
    const output = _1.map(source, x => x.a);
    await asyncEqual(output, [2]);
});
t0_1.test("map properties", async () => {
    const source = create([{ a: 1 }, { a: 2 }, { a: 3 }]);
    const output = _1.map(source, x => x.a);
    await asyncEqual(output, [1, 2, 3]);
});
t0_1.test("empty", async () => {
    const source = create([]);
    const output = _1.map(source, x => x.a);
    await asyncEqual(output, []);
});
t0_1.run();
function create(x) {
    return (async function* () {
        yield* x;
    })();
}
async function asyncEqual(a, b) {
    const i = a[Symbol.asyncIterator]();
    const j = isAsyncIterable(b)
        ? b[Symbol.asyncIterator]()
        : b[Symbol.iterator]();
    do {
        const x = await i.next();
        const y = await j.next();
        if (x.done != y.done) {
            return false;
        }
        if (x.done && y.done) {
            return true;
        }
        if (x.value !== y.value) {
            return false;
        }
    } while (true);
}
function isAsyncIterable(x) {
    return typeof x[Symbol.asyncIterator] === "function";
}
async function* empty() { }
//# sourceMappingURL=test.js.map